Crate turbocharger_impl

Crate turbocharger_impl 

This crate provides Turbocharger’s procedural macros.

Please refer to the turbocharger crate for details.

Macros

connection_local
remote_addr
user_agent

Attribute Macros

backend
Apply this to a pub async fn to make it available (over the network) to the JS frontend. Also apply to any structs used in backend function signatures.
server_only
Apply this to an item to make it available on the server target only.
wasm_only
Apply this to an item to make it available on the wasm target only.