This crate provides Turbocharger’s procedural macros.
Please refer to the turbocharger crate for details.
Macros
Attribute Macros
- backend
- Apply this to a
pub async fnto make it available (over the network) to the JS frontend. Also apply to anystructs used in backend function signatures. - server_
only - Apply this to an item to make it available on the server target only.
- wasm_
only - Apply this to an item to make it available on the wasm target only.